# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogment/api/message.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogment/api/message.proto',
  package='cogment',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x19\x63ogment/api/message.proto\x12\x07\x63ogment\"J\n\x1cMasterMessageDispatchRequest\x12\x15\n\rsend_to_actor\x18\x01 \x03(\r\x12\x13\n\x0bsend_to_env\x18\x02 \x01(\x08\"\x16\n\x14MessageDispatchReplyb\x06proto3'
)




_MASTERMESSAGEDISPATCHREQUEST = _descriptor.Descriptor(
  name='MasterMessageDispatchRequest',
  full_name='cogment.MasterMessageDispatchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='send_to_actor', full_name='cogment.MasterMessageDispatchRequest.send_to_actor', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send_to_env', full_name='cogment.MasterMessageDispatchRequest.send_to_env', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=38,
  serialized_end=112,
)


_MESSAGEDISPATCHREPLY = _descriptor.Descriptor(
  name='MessageDispatchReply',
  full_name='cogment.MessageDispatchReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=136,
)

DESCRIPTOR.message_types_by_name['MasterMessageDispatchRequest'] = _MASTERMESSAGEDISPATCHREQUEST
DESCRIPTOR.message_types_by_name['MessageDispatchReply'] = _MESSAGEDISPATCHREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MasterMessageDispatchRequest = _reflection.GeneratedProtocolMessageType('MasterMessageDispatchRequest', (_message.Message,), {
  'DESCRIPTOR' : _MASTERMESSAGEDISPATCHREQUEST,
  '__module__' : 'cogment.api.message_pb2'
  # @@protoc_insertion_point(class_scope:cogment.MasterMessageDispatchRequest)
  })
_sym_db.RegisterMessage(MasterMessageDispatchRequest)

MessageDispatchReply = _reflection.GeneratedProtocolMessageType('MessageDispatchReply', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGEDISPATCHREPLY,
  '__module__' : 'cogment.api.message_pb2'
  # @@protoc_insertion_point(class_scope:cogment.MessageDispatchReply)
  })
_sym_db.RegisterMessage(MessageDispatchReply)


# @@protoc_insertion_point(module_scope)
