// Copyright 2020 Artificial Intelligence Redefined <dev+cogment@ai-r.com>
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

syntax = "proto3";

package cogment;

import "cogment/api/common.proto";

// Expected metadata for all calls except `Version`:
//   - trial-id: The id of the trial
service TrialHooks {
  rpc OnPreTrial(PreTrialContext) returns (PreTrialContext) {}
  
  rpc Version(VersionRequest) returns (VersionInfo) {}
}

message PreTrialContext {
  string impl_name = 1;
  TrialParams params = 2;
  string user_id = 3;
}